#ifndef __LIBKYDESKTOPCTRL__H__
#define __LIBKYDESKTOPCTRL__H__

#ifdef __cplusplus
extern "C" {
#endif

#include <stdbool.h>

#define EXMLFILE        (500)
#define EJSONFILE       (499)
#define EDBUS           (498)

/**
 * dpkg 黑白名单管理
 */

typedef enum _kdk_deb_bwlist_type {
    DEB_NORMAL = 0,     //未开启黑白名单
    DEB_WHITELIST,      //白名单
    DEB_BLACKLIST,      //黑名单
} kdk_deb_bwlist_type;

typedef struct _kdk_deb_bwlist {
    char **debs;    //包名列表
    int count;      //包信息数量
} kdk_deb_bwlist;

/**
 * @brief 添加一个包到黑白名单中
 * @param type [in] 类型，参见kdk_deb_bwlist_type
 * @param deb [in] 包名
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_deb_bwlist_add(int type, const char *deb);

/**
 * @brief 删除一个包从黑白名单中
 * @param type [in] 类型，参见kdk_deb_bwlist_type
 * @param deb [in] 包名
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_deb_bwlist_del(int type, const char *deb);

/**
 * @brief 获取黑白名单开关标识
 * @return kdk_deb_bwlist_type
 */
extern int kdk_deb_bwlist_get_mode(void);

/**
 * @brief 设置黑白名单开关标识
 * @param type [in] 类型，参见kdk_deb_bwlist_type
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_deb_bwlist_set_model(int type);

/**
 * @brief 清空配置文件列表
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_deb_bwlist_clear();

/**
 * @brief 获取给白名单节点数据
 * @param type [in] 类型，参见kdk_deb_bwlist_type
 * @param list [in] 包信息列表
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_deb_bwlist_get_all(int type, kdk_deb_bwlist *list);

/**
 * @brief 释放kdk_deb_bwlist内存
 * @param list [in] 包信息列表
 */
extern void kdk_deb_bwlist_release(kdk_deb_bwlist *list);

#if 0
#endif

/**
 * 壁纸与屏保
 */

/**
 * @brief 设置壁纸
 * @param path [in] 图片文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_wallpaper_set_file(const char *path);

/**
 * @brief 设置屏保图片
 * @param path [in] 图片文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_screensaver_set_file(const char *path);

/**
 * @brief 设置系统屏保使能
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_screensaver_enable();

/**
 * @brief 设置系统屏保禁用
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_screensaver_disable();

/**
 * @brief 设置系统自动锁屏使能
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_screensaver_autolock_enable();

/**
 * @brief 设置系统自动锁屏禁用
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_screensaver_autolock_disable();

/**
 * @brief 设置系统自动屏保时间
 * @param tm [in] 空闲时间，单位分钟
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_screensaver_autolock_time(unsigned int tm);

#if 0
#endif

/**
 * 电源设置
 */

/**
 * @brief 设置台式机系统空闲时间开启挂起的时间
 * @param tm [in] 空闲时间，单位秒
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_powersetting_set_desktop_idle_hungup(unsigned int tm);

/**
 * @brief 获取台式机系统空闲时间开启挂起的时间
 * @return unsigned int 返回空闲时间，单位秒
 */
extern unsigned int kdk_powersetting_get_desktop_idle_hungup();

/**
 * @brief 设置台式机系统空闲时间关闭屏幕的时间
 * @param tm [in] 空闲时间，单位秒
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_powersetting_set_desktop_idle_closedisplay(unsigned int tm);

/**
 * @brief 获取台式机系统空闲时间关闭屏幕的时间
 * @return unsigned int 返回空闲时间，单位秒
 */
extern unsigned int kdk_powersetting_get_desktop_idle_closedisplay();

/**
 * @brief 设置笔记本系统空闲时间开启挂起的时间
 * @param tm [in] 空闲时间，单位秒
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_powersetting_set_laptop_idle_hungup(unsigned int tm);

/**
 * @brief 获取笔记本系统空闲时间开启挂起的时间
 * @return unsigned int 返回空闲时间，单位秒
 */
extern unsigned int kdk_powersetting_get_laptop_idle_hungup();

/**
 * @brief 设置笔记本系统空闲时间关闭屏幕的时间
 * @param tm [in] 空闲时间，单位秒
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_powersetting_set_laptop_idle_closedisplay(unsigned int tm);

/**
 * @brief 获取笔记本系统空闲时间关闭屏幕的时间
 * @return unsigned int 返回空闲时间，单位秒
 */
extern unsigned int kdk_powersetting_get_laptop_idle_closedisplay();

#if 0
#endif

/**
 * 控制面板功能管控
 */

typedef enum _kdk_controlpanel_module {
    CP_SYS = 0,
    CP_SYS_DISPLAY,
    CP_SYS_TOUCHSCREEN,
    CP_SYS_AUTOBOOT,
    CP_SYS_DEFAULTAPP,
    CP_SYS_POWER,

    CP_DT = 16,
    CP_DT_AREA,
    CP_DT_DAT,

    CP_ACNT = 32,
    CP_ACNT_CLOUD,
    CP_ACNT_USERINFO,

    CP_DEV = 48,
    CP_DEV_AUDIO,
    CP_DEV_KEYBOARD,
    CP_DEV_MOUSE,
    CP_DEV_PRINTER,
    CP_DEV_SHORTCUT,
    CP_DEV_TOUCHPAD,

    CP_NET = 64,
    CP_NET_CONNECT,
    CP_NET_PROXY,
    CP_NET_VINO,
    CP_NET_VPN,

    CP_NOTICE = 80,
    CP_NOTICE_ABOUT,
    CP_NOTICE_NOTICE,
    CP_NOTICE_EXPERIENCEPLAN,

    CP_PERSONAL = 96,
    CP_PERSONAL_BACKGROUND,
    CP_PERSONAL_FONTS,
    CP_PERSONAL_SCREENLOCK,
    CP_PERSONAL_SCREENSAVER,
    CP_PERSONAL_THEME,
    CP_PERSONAL_DESKTOP,

    CP_UPDATE = 112,
    CP_UPDATE_BACKUP,
    CP_UPDATE_DEFENDER,
    CP_UPDATE_UPGRADE
} kdk_controlpanel_module;

/**
 * @brief 设置控制面板功能是否可见
 * @param module [in] 模块，参见kdk_controlpanel_module
 * @param visible [in] 是否可见；
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_controplpanel_set_module_visible(int module, bool visible);

/**
 * @brief 获取控制面板功能是否可见
 * @param module [in] 模块，参见kdk_controlpanel_module
 * @return true为可见，false为隐藏
 */
extern bool kdk_controlpanel_get_module_visible(int module);

#if 0
#endif

/**
 * 水印管理
 */

/**
 * @brief 创建空水印
 * @param name [in] 水印名称
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_watermark_create(const char *name);

/**
 * @brief 删除水印
 * @param name [in] 水印名称
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_watermark_delete(const char *name);

/**
 * @brief 设置水印是否可见
 * @param name [in] 水印名称
 * @param visibe [in] 是否可见
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_watermark_set_visibe(const char *name, bool visibel);

/**
 * @brief 获取水印是否显示
 * @param name [in] 水印名称
 * @return bool 返回true表示可见，返回false表示隐藏
 */
extern bool kdk_watermark_get_visibe(const char *name);

/**
 * @brief 设置水印用户名是否显示
 * @param name [in] 水印名称
 * @param visible [in] 是否可见
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_watermark_set_username_visible(const char *name, bool visible);

/**
 * @brief 获取水印用户是否显示
 * @param name [in] 水印名称
 * @return bool 返回true表示可见，返回false表示隐藏
 */
extern bool kdk_watermark_get_username_visible(const char *name);

/**
 * @brief 设置水印时间戳是否显示
 * @param name [in] 水印名称
 * @param visible [in] 是否可见
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_watermark_set_timestamp_visible(const char *name, bool visible);

/**
 * @brief 获取水印时间戳是否显示
 * @param name [in] 水印名称
 * @return bool 返回true表示可见，返回false表示隐藏
 */
extern bool kdk_watermark_get_timestamp_visible(const char *name);

/**
 * @brief 设置水印内容是否显示
 * @param name [in] 水印名称
 * @param visible [in] 是否可见
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_watermark_set_context_visible(const char *name, bool visible);

/**
 * @brief 获取水印内容是否显示
 * @param name [in] 水印名称
 * @return bool 返回true表示可见，返回false表示隐藏
 */
extern bool kdk_watermark_get_context_visible(const char *name);

/**
 * @brief 设置水印透明度
 * @param name [in] 水印名称
 * @param trans [in] 透明度， 0-100，0全透明，100不透明
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_watermark_set_opacity(const char *name, unsigned int trans);

/**
 * @brief 获取水印透明度
 * @param name [in] 水印名称
 * @return unsigned int 表示透明度，0-100，0全透明，100不透明
 */
extern unsigned int kdk_watermark_get_opacity(const char *name);

/**
 * @brief 设置水印时间格式
 * @param name [in] 水印名称
 * @param fmt [in] 时间格式
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_watermark_set_timeformat(const char *name, const char *fmt);

/**
 * @brief 获取水印时间格式
 * @param name [in] 水印名称
 * @param fmt [out] 时间格式
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_watermark_get_timeformat(const char *name, char *fmt);

/**
 * @brief 设置水印内容
 * @param name [in] 水印名称
 * @param context [in] 水印内容
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_watermark_set_context(const char *name, const char *context);

/**
 * @brief 获取水印内容
 * @param name [in] 水印名称
 * @param context [out] 水印内容
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_watermark_get_context(const char *name, char *context);

/**
 * @brief 设置水印字体大小
 * @param name [in] 水印名称
 * @param size [in] 水印文字大小
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_watermark_set_fontsize(const char *name, int size);

/**
 * @brief 获取水印字体大小
 * @param name [in] 水印名称
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_watermark_get_fontsize(const char *name);

/**
 * @brief 设置水印位置
 * @param name [in] 水印名称
 * @param left [in] 中心点左边距离
 * @param top [in] 中心点右边距离
 * @param horizontal [in] 横向大小
 * @param vertical [in] 纵向大小
 * @return int 返回0表示成功，返回非零表示失败
 * @remark 这里的数字指的是相对大小，例子中展示的是水印的默认设置，它代表的含义是水印中心位置在以左上角为基准点，屏幕横向50%，纵向50%的位置（也就是屏幕正中央）；水印大小为横向大小100%，纵向大小100%（也就是整个屏幕）；
 */
extern int kdk_watermark_set_position(const char *name, unsigned int left, unsigned int top, unsigned int horizontal, unsigned int vertical);

/**
 * @brief 获取水印位置
 * @param name [in] 水印名称
 * @param left [out] 中心点左边距离
 * @param top [out] 中心点右边距离
 * @param horizontal [out] 横向大小
 * @param vertical [out] 纵向大小
 * @return int 返回0表示成功，返回非零表示失败
 * @remark 这里的数字指的是相对大小，例子中展示的是水印的默认设置，它代表的含义是水印中心位置在以左上角为基准点，屏幕横向50%，纵向50%的位置（也就是屏幕正中央）；水印大小为横向大小100%，纵向大小100%（也就是整个屏幕）；
 */
extern int kdk_watermark_get_position(const char *name, unsigned int *left, unsigned int *top, unsigned int *horizontal, unsigned int *vertical);

/**
 * @brief 设置水印间距
 * @param name [in] 水印名称
 * @param horizontal [in] 水平间距
 * @param vertical [in] 垂直间距
 * @return int 返回0表示成功，返回非零表示失败
 * @remark 如果是[-1,-1]则表示只显示一个（默认只显示一个），单位是pt
 */
extern int kdk_watermark_set_density(const char *name, int horizontal, int vertical);

/**
 * @brief 获取水印间距
 * @param name [in] 水印名称
 * @param horizontal [out] 水平间距
 * @param vertical [out] 垂直间距
 * @return int 返回0表示成功，返回非零表示失败
 * @remark 如果是[-1,-1]则表示只显示一个（默认只显示一个），单位是pt
 */
extern int kdk_watermark_get_density(const char *name, int *horizontal, int *vertical);

/**
 * @brief 设置水印旋转角度
 * @param name [in] 水印名称
 * @param rotate [in] 水印旋转角度,角度制,默认0,可在(-360~360之间设置）
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_watermark_set_rotate(const char *name, int rotate);

/**
 * @brief 获取水印旋转角度
 * @param name [in] 水印名称
 * @return int 返回水印旋转角度，角度值，可在（-360~360之间设置）
 */
extern int kdk_watermark_get_rotate(const char *name);

/**
 * @brief 设置水印字体颜色
 * @param name [in] 水印名称
 * @param r [in] RGB中R色值
 * @param g [in] RGB中G色值
 * @param b [in] RGB中B色值
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_watermark_set_fontcolor(const char *name, unsigned int r, unsigned int g, unsigned int b);

/**
 * @brief 获取水印颜色
 * @param name [in] 水印名称
 * @param r [out] RGB中R色值
 * @param g [out] RGB中G色值
 * @param b [out] RGB中B色值
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_watermark_get_fontcolor(const char *name, unsigned int *r, unsigned int *g, unsigned int *b);

#if 0
#endif

/**
 * 登录界面管控
 */

typedef enum _kdk_model_type {
    MODEL_NORMAL = 0,
    MODEL_BLACKLIST,
    MODEL_WHITELIST,
} kdk_model_type;

/**
 * @brief 设置登录界面管控模式
 * @param type [in] 管控类型，参见kdk_model_type
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_greeter_set_model(int type);

/**
 * @brief 添加用户到黑名单
 * @param username [in] 用户名
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_greeter_add_blacklist(const char *username);

/**
 * @brief 删除用户从黑名单
 * @param username [in] 用户名
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_greeter_del_blacklist(const char *username);

/**
 * @brief 清空黑名单列表
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_greeter_clear_blacklist();

/**
 * @brief 添加用户到白名单
 * @param username [in] 用户名
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_greeter_add_whitelist(const char *username);

/**
 * @brief 删除用户从白名单
 * @param username [in] 用户名
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_greeter_del_whitelist(const char *username);

/**
 * @brief 清空白名单列表
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_greeter_clear_whitelist();

#if 0
#endif

/**
 * @brief 设置任务栏界面管控模式
 * @param type [in] 管控类型，参见kdk_model_type
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_taskpanel_set_model(int type);

/**
 * @brief 添加应用快捷方式到任务栏界面黑名单
 * @param appname [in] 应用名
 * @param path [in] desktop文件路径
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_taskpanel_add_blacklist(const char *appname, const char *path);

/**
 * @brief 删除应用快捷方式从任务栏界面黑名单
 * @param appname [in] 应用名
 * @param path [in] desktop文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_taskpanel_del_blacklist(const char *appname, const char *path);

/**
 * @brief 清空任务栏界面黑名单列表
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_taskpanel_clear_blacklist();

/**
 * @brief kdk_taskpanel_add_whitelist
 * @param appname [in] 应用名
 * @param path [in] desktop文件路径
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_taskpanel_add_whitelist(const char *appname, const char *path);

/**
 * @brief kdk_taskpanel_del_whitelist
 * @param appname [in] 应用名
 * @param path [in] desktop文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_taskpanel_del_whitelist(const char *appname, const char *path);

/**
 * @brief 清空任务栏界面白名单列表
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_taskpanel_clear_whitelist();

#if 0
#endif

/**
 * 开始菜单应用管控
 */

/**
 * @brief 设置开始菜单界面管控模式
 * @param type [in] 管控类型，参见kdk_model_type
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_startmenu_set_model(int type);

/**
 * @brief 添加应用快捷方式到开始菜单界面黑名单
 * @param appname [in] 应用名
 * @param path [in] desktop文件路径
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_startmenu_add_blacklist(const char *appname, const char *path);

/**
 * @brief 删除应用快捷方式从开始菜单界面黑名单
 * @param appname [in] 应用名
 * @param path [in] desktop文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_startmenu_del_blacklist(const char *appname, const char *path);

/**
 * @brief 清空开始菜单界面黑名单列表
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_startmenu_clear_blacklist();

/**
 * @brief 添加应用快捷方式到白名单
 * @param appname [in] 应用名
 * @param path [in] desktop文件路径
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_startmenu_add_whitelist(const char *appname, const char *path);

/**
 * @brief 删除开始菜单应用从白名单
 * @param appname [in] 应用名
 * @param path [in] desktop文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_startmenu_del_whitelist(const char *appname, const char *path);

/**
 * @brief 清空开始菜单界面白名单列表
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_startmenu_clear_whitelist();

#if 0
#endif

/**
 * 桌面应用管控
 */

/**
 * @brief 设置桌面应用管控模式
 * @param type [in] 管控类型，参见kdk_model_type
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_desktop_set_model(int type);

/**
 * @brief 添加应用快捷方式到桌面应用黑名单
 * @param appname [in] 应用名
 * @param path [in] desktop文件路径
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_desktop_add_blacklist(const char *appname, const char *path);

/**
 * @brief 删除应用快捷方式从桌面应用黑名单
 * @param appname [in] 应用名
 * @param path [in] desktop文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_desktop_del_blacklist(const char *appname, const char *path);

/**
 * @brief 清空桌面应用黑名单列表
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_desktop_clear_blacklist();

/**
 * @brief 添加应用快捷方式到白名单
 * @param appname [in] 应用名
 * @param path [in] desktop文件路径
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_desktop_add_whitelist(const char *appname, const char *path);

/**
 * @brief 删除桌面应用从白名单
 * @param appname [in] 应用名
 * @param path [in] desktop文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_desktop_del_whitelist(const char *appname, const char *path);

/**
 * @brief 清空桌面应用白名单列表
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_desktop_clear_whitelist();

#if 0
#endif

/**
 * 软件商店应用管控
 */

/**
 * @brief 设置软件商店应用管控模式
 * @param type [in] 管控类型，参见kdk_model_type
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_appstore_set_model(int type);

/**
 * @brief 添加应用快捷方式到软件商店应用黑名单
 * @param appname [in] 应用名
 * @param path [in] desktop文件路径
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_appstore_add_blacklist(const char *appname);

/**
 * @brief 删除应用快捷方式从软件商店应用黑名单
 * @param appname [in] 应用名
 * @param path [in] desktop文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_appstore_del_blacklist(const char *appname);

/**
 * @brief 清空软件商店应用黑名单列表
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_appstore_clear_blacklist();

/**
 * @brief 添加应用快捷方式到白名单
 * @param appname [in] 应用名
 * @param path [in] desktop文件路径
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_appstore_add_whitelist(const char *appname);

/**
 * @brief 删除软件商店应用从白名单
 * @param appname [in] 应用名
 * @param path [in] desktop文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_appstore_del_whitelist(const char *appname);

/**
 * @brief 清空软件商店应用白名单列表
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_appstore_clear_whitelist();

#if 0

/**
 * USB存储设备管控
 */

typedef enum _kdk_usbstorage_status {
    US_DISABLE = 0,
    US_READONLY,
    US_ENABLE
} kdk_usbstorage_status;

/**
 * @brief 获取存储设备状态
 * @return kdk_usbstorage_status
 */
extern int kdk_usbstorage_get_status();

/**
 * @brief 设置存储设备状态
 * @param status [in] 管控状态，参见kdk_usbstorage_status
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_usbstorage_set_status(int status);

#if 0
#endif

/**
 * USB摄像头管控
 */

typedef enum _kdk_usbcamera_status {
    USBCAMERA_DISABLE = 0,
    USBCAMERA_ENABLE,
} kdk_usbcamera_status;

/**
 * @brief 获取USB摄像头状态
 * @return kdk_usbcamrea_status
 */
extern int kdk_usbcamera_get_status();

/**
 * @brief 设置USB摄像头状态
 * @param status [in] 管控状态，参见kdk_usbcamera_status
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_usbcamera_set_status(int status);

#if 0
#endif

/**
 * USB设备黑白名单
 */

typedef struct _kdk_usbdevice {
    char pid[32];
    char vid[32];
    char serial[64];
} kdk_usbdevice;

/**
 * @brief 设置USB黑白名单管控类型
 * @param type [in] 管控类型，参见kdk_model_type
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_usbdevice_set_model(int type);

/**
 * @brief 添加USB设备到黑名单
 * @param pid [in] product id
 * @param vid [in] vender id
 * @param serial [in] serial number
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_usbdevice_add_blacklist(const char *pid, const char *vid, const char *serial);

/**
 * @brief kdk_usbdevice_del_blacklist
 * @param pid [in] product id
 * @param vid [in] vender id
 * @param serial [in] serial number
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_usbdevice_del_blacklist(const char *pid, const char *vid, const char *serial);

/**
 * @brief kdk_usbdevice_get_blacklist
 * @param devs [out] 黑名单列表，参见kdk_usbdevice，使用free进行释放
 * @param count [out] 列表内容数量
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_usbdevice_get_blacklist(kdk_usbdevice **devs, int *count);

/**
 * @brief kdk_usbdevice_add_whitelist
 * @param pid [in] product id
 * @param vid [in] vender id
 * @param serial [in] serial number
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_usbdevice_add_whitelist(const char *pid, const char *vid, const char *serial);

/**
 * @brief kdk_usbdevice_del_whitelist
 * @param pid [in] product id
 * @param vid [in] vender id
 * @param serial [in] serial number
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_usbdevice_del_whitelist(const char *pid, const char *vid, const char *serial);

/**
 * @brief kdk_usbdevice_get_whitelist
 * @param devs [out] 黑名单列表，参见kdk_usbdevice，使用free进行释放
 * @param count [out] 列表内容数量
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_usbdevice_get_whitelist(kdk_usbdevice **devs, int *count);

#if 0
#endif

/**
 * 网卡管控
 */

/**
 * @brief 设置网卡管控状态
 * @param status [in] true为开启管控，false为关闭管控
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_networkcard_set_status(bool status);

/**
 * @brief 获取网卡管控状态
 * @return bool true为开启管控，false为关闭管控
 */
extern bool kdk_networkcard_get_status();

#if 0
#endif

/**
 * 声卡管控
 */

/**
 * @brief 设置声卡管控状态
 * @param status [in] true为开启管控，false为关闭管控
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_soundcard_set_status(bool status);

/**
 * @brief 获取声卡管控状态
 * @return bool true为开启管控，false为关闭管控
 */
extern bool kdk_soundcard_get_status();

/**
 * @brief 设置音量
 * @param value [in] 音量值
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_soundcard_set_volume(int value);

/**
 * @brief 获取音量
 * @return int 音量值
 */
extern int kdk_soundcard_get_volume();

/**
 * @brief 增加音量
 * @param value [in] 音量增量
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_soundcard_increase_volume(int value);

/**
 * @brief 降低音量
 * @param value [in] 音量减量
 * @return  int 返回0表示成功，返回非零表示失败
 */
extern int kdk_soundcard_decrease_volume(int value);

#if 0
#endif

/**
 * 手机管控
 */

/**
 * @brief 设置手机管控状态
 * @param status [in] true为开启管控，false为关闭管控
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_phone_set_status(bool status);

/**
 * @brief 获取手机控状态
 * @return bool true为开启管控，false为关闭管控
 */
extern bool kdk_phone_get_status();

#if 0
#endif

/**
 * 光驱管控
 */

/**
 * @brief 设置光驱管控状态
 * @param status [in] true为开启管控，false为关闭管控
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_cdrom_set_status(bool status);

/**
 * @brief 获取光驱控状态
 * @return bool true为开启管控，false为关闭管控
 */
extern bool kdk_cdrom_get_status();

#endif

#ifdef __cplusplus
}
#endif

#endif//__LIBKYDESKTOPCTRL__H__
